@@ -100,10 +100,12 @@ typedef struct {
 	char *atIcon;
 	char *npSongFormat;
 	char *npStationFormat;
-	char *listSongFormat;
+	char *listSongFormat, *timeFormat;
 	char *fifo;
 	char *rpcHost, *rpcTlsPort, *partnerUser, *partnerPassword, *device, *inkey, *outkey, *caBundle;
+	char *audioPipe;
 	char keys[BAR_KS_COUNT];
+	int sampleRate;
 	BarMsgFormatStr_t msgFormat[MSG_COUNT];
 } BarSettings_t;
 
